Module color

Module color 

Unified color conversion between anstyle and ratatui.

This module provides the single correct mapping from anstyle::Color to ratatui::style::Color. Previous implementations in vtcode-commons and vtcode-tui had bugs mapping Magenta and bright variants to incorrect ratatui colors.

Functions

anstyle_to_ratatui_color
Convert an anstyle::Color to a ratatui::style::Color.